"""
    Created on 2012-01-20
    @author: jldupont
"""
import zmq
import logging,sys,os, json


def run(sock_pub=None, topic=None, json_mode=None, filter_topics=[]):

    try:
        ctx = zmq.Context()
        s = ctx.socket(zmq.PUB)
        s.bind(sock_pub)
        logging.info("Connected to socket: %s" % sock_pub)
    except Exception:
        raise Exception("Can't connect a socket to address: %s" % sock_pub)

    ppid=os.getppid()
    logging.info("Parent pid: %s" % ppid)
    logging.info("Starting loop...")    
    while True:
        
        ### protection against broken pipe
        if os.getppid()!=ppid:
            logging.warning("Parent process terminated... exiting")
            break
        
        iline=sys.stdin.readline().strip()
        
              
        if json_mode:
            try:
                jso=json.loads(iline)
            except:
                logging.warning("Can't decode json from: %s" % iline)
                continue
            
            topic=jso.get("topic", None)
            if topic is None:
                logging.warning("Missing 'topic' key in: %s" % iline)
                continue
            topic=str(topic)
            msg=json.dumps(jso)
        else:
            msg=iline   
            if topic is None:
                try:
                    topic, sep, msg=iline.partition(":")
                    assert(sep==":")
                    assert(len(topic)>0)
                except:
                    logging.warning("Invalid format, expecting:  'topic: msg'")
                    continue

        ## FILTER-OUT
        if topic in filter_topics:
            continue
    
        try:
            s.send_multipart([topic, msg])
        except Exception,e:
            logging.warning("Error sending on topic '%s': %s -- %s" % (topic, msg, str(e)))
        
    


"""
    Created on 2012-01-20
    @author: jldupont
"""
import zmq
import logging


def run(sock_pub=None, sock_sub=None):

    try:
        ctx = zmq.Context()
        ss = ctx.socket(zmq.SUB)
        ss.connect(sock_sub)
        ss.setsockopt(zmq.SUBSCRIBE, "")
        logging.info("Connected to SUB socket: %s" % sock_sub)
    except Exception:
        raise Exception("Can't connect SUB socket to address: %s" % sock_sub)
    
    try:
        ctx = zmq.Context()
        sp = ctx.socket(zmq.PUB)
        sp.bind(sock_pub)
        logging.info("Connected to PUB socket: %s" % sock_pub)        
    except Exception:
        raise Exception("Can't connect a socket to address: %s" % sock_pub)

    
    logging.info("Starting loop...")
    while True:
        
        topic, msg = ss.recv_multipart()    
        sp.send_multipart([topic, msg])



"""
    Created on 2012-01-20
    @author: jldupont
"""
import os
import zmq
import logging, sys

def run(sock_source=None, topics=None):

    try:
        ctx = zmq.Context()
        s = ctx.socket(zmq.SUB)
        s.connect(sock_source)
    except Exception:
        raise Exception("Can't connect a socket to address: %s" % sock_source)
    
    if topics is None or topics=="":
        logging.info("* Snooping mode engaged")
        topics=["",]
    
    try:
        for topic in topics:
            s.setsockopt(zmq.SUBSCRIBE, topic)
            if topic:
                logging.info("Subscribed to topic: %s" % topic)
    except:
        raise Exception("Error subscribing to topic '%s'" % topic)
    
    ppid=os.getppid()
    logging.info("Parent pid: %s" % ppid)
    logging.info("Starting loop...")
    while True:
        topic, msg = s.recv_multipart()
        sys.stdout.write('%s: %s' % (topic, msg))
        
        ### protection against broken pipe
        if os.getppid()!=ppid:
            logging.warning("Parent process terminated... exiting")
            break

    


#!/usr/bin/env python
"""
    Jean-Lou Dupont's ZeroMQ scripts
    
    Created on 2012-01-19
    @author: jldupont
"""
__author__  ="Jean-Lou Dupont"
__version__ ="0.2.11"

DESC="""
Overview
--------

Collection of 0mq related scripts

* jld0sub: subscribe to topics, output to stdout w/wo JSON
* jld0pub: publish to a topic, input from stdin w/wo JSON
* jld0fabric: fabric to publish/subscribe pattern

"""


from distutils.core import setup
from setuptools import find_packages


setup(name=         'jldzeromq',
      version=      __version__,
      description=  'Collection of ZeroMQ related tools',
      author=       __author__,
      author_email= 'jl@jldupont.com',
      url=          'http://www.systemical.com/doc/opensource/jldzeromq',
      package_dir=  {'': "src",},
      packages=     find_packages("src"),
      scripts=      ['src/scripts/jld0sub',
                     'src/scripts/jld0pub',
                     'src/scripts/jld0fabric',  
                     ],
      zip_safe=False
      ,long_description=DESC
      ,install_requires=[ "pyzmq",
                         ]
      )

#############################################

f=open("latest", "w")
f.write(str(__version__)+"\n")
f.close()

